==> ginsu-0.5.3.tar.gz: ginsu-0.5.3/ExampleConf.hs <==
module ExampleConf(exampleConf) where
{-# NOINLINE exampleConf #-}
exampleConf :: String
exampleConf = unlines [
    "#---------------------------------------------------",
    "# this file should be placed in ~/.gale/ginsu.config",
    "#---------------------------------------------------",
    "",
    "#the setting in this sample file coorespond to the defaults",
    "",
    "######################",
    "# Definately set these",
    "######################",
    "",
    "# set to your gale domain (usually taken from enviornment, MUST be set somewhere)",
    "#GALE_DOMAIN gale.org",
    "",
    "",
    "# GALE_SUBSCRIBE is a list of all categories you wish to subscribe too.",
    "# the default is some common public categories and your private puffs.",
    "",
    "GALE_SUBSCRIBE pub@ofb.net local@ofb.net test.ginsu@ofb.net $GALE_ID",
    "",
    "# GALE_NAME should be set to your real name.",
    "GALE_NAME Ginsu User $LOGNAME",
    "",
    "",
    "###################",
    "# perhaps set these",
    "###################",
    "",
    "#GALE_ID should be set to your GALE_ID. the default is to append your login to your GALE_DOMAIN.",
    "#GALE_ID user@gale.org",
    "",
    "",
    "# editor to use for puff composition (else $VISUAL then $EDITOR used)",
    "#EDITOR vim",
    "",
    "# GALE_PROXY",
    "#  gale server to use in preference to all others, you should not need to set",
    "#  this unless you are behind a firewall or your own GALE_DOMAIN servers are not",
    "#  suitable for some reason.",
    "#GALE_PROXY gale.org",
    "",
    "",
    "# MARK_[123..] sets the initial filter for a given marked screen. use the",
    "# number keys to quickly switch to a mark.",
    "#",
    "# the default has '7' show puffs to or from you, ",
    "# '8' shows traffic about gale and '9' filters spoilers away.",
    "",
    "MARK_7 ~c:$GALE_ID ; ~a:$GALE_ID",
    "MARK_8 ~c:pub.gale@ofb.net ; ~c:pub.rfc",
    "MARK_9 !~k:spoil",
    "",
    "",
    "# beep on any puffs matching the following filters",
    "BEEP ~c:$GALE_ID   ",
    "",
    "",
    "# number of puffs to store in pufflog on exit.",
    "PUFFLOG_SIZE 150",
    "",
    "# charset, one of utf8, latin1, or ascii. if not set, will try to determine it from $LANG",
    "# this only affects what format it assumes you are editing puffs in. locale settings are ",
    "# always used for the UI",
    "#CHARSET latin1",
    "",
    "# when replying to a puff, keep these keywords",
    "PRESERVED_KEYWORDS ketchup catchup tangent spoiler spoilers nolog",
    "",
    "# on startup, run this macro",
    "ON_STARTUP <End>",
    "",
    "# uncomment this if you are having trouble with terminal resizing.",
    "#DISABLE_SIGWINCH True",
    "",
    "#dispose of blank lines at the begining or end of puffs",
    "TRIM_BLANKLINES true",
    "",
    "#default key bindings",
    "bind <F1> show_help_screen ",
    "bind ? show_help_screen",
    "#bind <F2> show_main_index ",
    "bind <F3> show_presence_status ",
    "",
    "bind j next_puff",
    "bind k previous_puff",
    "bind <Down> next_puff",
    "bind <Up> previous_puff",
    "",
    "bind <Home> first_puff",
    "bind <End> last_puff",
    "",
    "bind <Enter> next_line",
    "bind <C-E> next_line",
    "",
    "bind <BackSpace> previous_line",
    "bind <C-Y> previous_line",
    "",
    "bind <C-F> next_page",
    "bind <PgDown> next_page",
    "bind <C-B> previous_page",
    "bind <PgUp> previous_page",
    "",
    "bind <C-D> forward_half_page",
    "bind <C-U> backward_half_page",
    "",
    "bind d show_puff_details",
    "",
    "bind c prompt_new_filter",
    "bind / prompt_new_filter",
    "bind ~ prompt_new_filter_twiddle",
    "bind u pop_one_filter",
    "bind U pop_all_filters",
    "bind ! invert_filter",
    "bind x swap_filters",
    "",
    "bind a filter_current_author",
    "bind t filter_current_thread",
    "bind T filter_current_thread",
    "",
    "bind m set_mark",
    "bind C recall_combine_mark",
    "",
    "bind f follow_up",
    "bind p new_puff",
    "bind r reply_to_author",
    "bind g group_reply",
    "bind R resend_puff",
    "",
    "bind N modify_presence_string",
    "",
    "bind <C-r> reconnect_to_servers",
    "bind E edit_config_file",
    "bind q ask_quit",
    "bind Q fast_quit",
    "bind <C-l> redraw_screen",
    " ",
  ""]

==> ginsu-0.7.0.tar.gz: ginsu-0.7.0/ExampleConf.hs <==
module ExampleConf(exampleConf) where
{-# NOINLINE exampleConf #-}
exampleConf :: String
exampleConf = unlines [
    "#---------------------------------------------------",
    "# this file should be placed in ~/.gale/ginsu.config",
    "#---------------------------------------------------",
    "",
    "#the setting in this sample file coorespond to the defaults",
    "",
    "######################",
    "# Definately set these",
    "######################",
    "",
    "# set to your gale domain (usually taken from enviornment, MUST be set somewhere)",
    "#GALE_DOMAIN gale.org",
    "",
    "",
    "# GALE_SUBSCRIBE is a list of all categories you wish to subscribe too.",
    "# the default is some common public categories and your private puffs.",
    "",
    "GALE_SUBSCRIBE pub@ofb.net local@ofb.net test.ginsu@ofb.net $GALE_ID",
    "",
    "# GALE_NAME should be set to your real name.",
    "GALE_NAME Ginsu User $LOGNAME",
    "",
    "PUFF_DATE_FORMAT %a %H:%M:%S",
    "",
    "###################",
    "# perhaps set these",
    "###################",
    "",
    "#GALE_ID should be set to your GALE_ID. the default is to append your login to your GALE_DOMAIN.",
    "#GALE_ID user@gale.org",
    "",
    "",
    "# editor to use for puff composition (else $VISUAL then $EDITOR used)",
    "#EDITOR vim",
    "",
    "# GALE_PROXY",
    "#  gale server to use in preference to all others, you should not need to set",
    "#  this unless you are behind a firewall or your own GALE_DOMAIN servers are not",
    "#  suitable for some reason.",
    "#GALE_PROXY gale.org",
    "",
    "",
    "# MARK_[123..] sets the initial filter for a given marked screen. use the",
    "# number keys to quickly switch to a mark.",
    "#",
    "# the default has '7' show puffs to or from you, ",
    "# '8' shows traffic about gale and '9' filters spoilers away.",
    "",
    "MARK_7 ~c:$GALE_ID ; ~a:$GALE_ID",
    "MARK_8 ~c:pub.gale@ofb.net ; ~c:pub.rfc",
    "MARK_9 !~k:spoil",
    "",
    "",
    "# beep on any puffs matching the following filters",
    "BEEP ~c:$GALE_ID   ",
    "",
    "",
    "# number of puffs to store in pufflog on exit.",
    "PUFFLOG_SIZE 150",
    "",
    "# charset, one of utf8, latin1, or ascii. if not set, will try to determine it from $LANG",
    "# this only affects what format it assumes you are editing puffs in. locale settings are ",
    "# always used for the UI",
    "#CHARSET latin1",
    "",
    "# when replying to a puff, keep these keywords",
    "PRESERVED_KEYWORDS ketchup catchup tangent spoiler spoilers nolog",
    "",
    "# on startup, run this macro",
    "ON_STARTUP <End>",
    "",
    "# uncomment this if you are having trouble with terminal resizing.",
    "#DISABLE_SIGWINCH True",
    "",
    "#dispose of blank lines at the begining or end of puffs",
    "TRIM_BLANKLINES true",
    "",
    "BROWSER links",
    "",
    "apphook WikiWord ",
    "        '([[:space:]]|^)(([[:upper:]][[:lower:]]+){2,})([[:space:]]|$)' ",
    "        '$BROWSER http://wiki.ofb.net/?$2'",
    "        '$2'",
    "",
    "apphook Url",
    "        '(http|ftp)s?://(%[[:digit:]A-Fa-f][[:digit:]A-Fa-f]|[-_.!~*'';/?:@&=+$,[:alnum:]])+'",
    "        '$BROWSER ''$0'''",
    "",
    "#default key bindings",
    "",
    "bind <F1> show_help_screen ",
    "bind ? show_help_screen",
    "#bind <F2> show_main_index ",
    "bind <F3> show_presence_status ",
    "",
    "bind j next_puff",
    "bind k previous_puff",
    "bind <Down> next_puff",
    "bind <Up> previous_puff",
    "",
    "bind <Home> first_puff",
    "bind <End> last_puff",
    "bind G last_puff",
    "",
    "bind <Enter> next_line",
    "bind <C-E> next_line",
    "",
    "bind <BackSpace> previous_line",
    "bind <C-Y> previous_line",
    "",
    "bind <C-F> next_page",
    "bind <PageDown> next_page",
    "bind <C-B> previous_page",
    "bind <PageUp> previous_page",
    "",
    "bind <C-D> forward_half_page",
    "bind <C-U> backward_half_page",
    "",
    "bind d show_puff_details",
    "",
    "bind c prompt_new_filter",
    "bind / prompt_new_filter_slash",
    "bind ~ prompt_new_filter_twiddle",
    "bind u pop_one_filter",
    "bind U pop_all_filters",
    "bind ! invert_filter",
    "bind x swap_filters",
    "",
    "bind a filter_current_author",
    "bind t filter_current_thread",
    "bind T filter_current_thread",
    "",
    "# marks",
    "bind m set_mark",
    "bind <SingleQuote> recall_mark",
    "bind M set_filter_mark",
    "bind <DoubleQuote> recall_filter_mark",
    "bind C recall_combine_mark",
    "",
    "bind f follow_up",
    "bind p new_puff",
    "bind r reply_to_author",
    "bind g group_reply",
    "bind R resend_puff",
    "",
    "bind N modify_presence_string",
    "",
    "bind <C-r> reconnect_to_servers",
    "bind E edit_config_file",
    "bind q ask_quit",
    "bind Q fast_quit",
    "bind <C-l> redraw_screen",
    "bind v goto_match",
    "bind S show_status_screen",
    " ",
  ""]
